/* Construct w/h series from PSID data.
   First version: Oct. 2001.
   Merge 1988 to 1990 files. Pick wage and hours worked info */

libname  tempdir 'd:\elast_data\temp\';
filename fileref 'd:\elast_data\outdata\data89.asc';
filename infile0 'd:\psid\data68_93\68_93ind.dat';
filename infile1 'd:\psid\data88\88fam.dat';
filename infile2 'd:\psid\data89\89fam.dat';
filename infile3 'd:\psid\data90\90fam.dat';


    /* Read in 1988-1990 cross-year individual file and select variables
      needed for analysis. */

data tempdir.ind88_90(compress=no
                           rename=(V30570=ID88 V30606=ID89 V30642=ID90
                           V30573=AGE88 V30609=AGE89 V30645=AGE90
                           V30584=EDUC88 V32000=SEX));
infile infile0 LRECL=2189;

input
       V30001  2-5
       V30002  6-8
       V30570  1343-1346
       V30571  1347-1348
       V30572  1349-1350
       V30573  1351-1352
       V30584  1375-1376
       V30606  1432-1435
       V30607  1436-1437
       V30608  1438-1439
       V30609  1440-1441
       V30642  1521-1525
       V30643  1526-1527
       V30644  1528-1529
       V30645  1530-1531
       V32000  2060;
label
       V30001 = "1968 INTERVIEW NUMBER 68"
       V30002 = "PERSON NUMBER         68"
       V30570 = "1988 INTERVIEW NUMBER"
       V30571 = "SEQUENCE NUMBER       88"
       V30572 = "RELATIONSHIP TO HEAD  88"
       V30573 = "AGE OF INDIVIDUAL     88"
       V30584 = "COMPLETED EDUCATION   88"
       V30606 = "1989 INTERVIEW NUMBER"
       V30607 = "SEQUENCE NUMBER       89"
       V30608 = "RELATIONSHIP TO HEAD  89"
       V30609 = "AGE OF INDIVIDUAL     89"
       V30642 = "1990 INTERVIEW NUMBER"
       V30643 = "SEQUENCE NUMBER       90"
       V30644 = "RELATIONSHIP TO HEAD  90"
       V30645 = "AGE OF INDIVIDUAL     90"
       V32000 = "SEX OF INDIVIDUAL";

/* Missing values */
IF V30573=99 THEN V30573=.;
IF V30584 IN(99,0) THEN V30584=.;
IF V30609=99 THEN V30609=.;
IF V30645=99 THEN V30645=.;

/* Select those men who were always heads 1988-1990 */
if (V32000 = 1) and
    (V30571 = 1 and V30572 = 10) and
    (V30607 = 1 and V30608 = 10) and
    (V30643 = 1 and V30644 = 10);

drop V30571 V30572 V30607 V30608 V30643 V30644;

run;


/* ======== 1988 ======== */

/* Read in 1988 family file and select variables needed for analysis */
data tempdir.fam88(compress=no
                  rename=(V14802=ID88 V15162=OCC88 V15154=EMPSTAT88 V15168=WH88 
                          V14835=H88 V15136=MARSTAT88));
infile infile1 LRECL=2721;
input
       V14802  4-7
       V14835  76-79
       V14913  218-223
       V14915  225-229
       V14916  230-235
       V14917  236-240
       V14918  241-245
       V15136  819
       V15154  839
       V15162  848-850
       V15168  864-867;
label
       V14802 = "1988 INTERVIEW NUMBER"
       V14835 = "HD ANN WRK HRS IN 87"
       V14913 = "HEAD 87 WAGES"
       V14915 = "HD BONUS/OT/COMM 87"
       V14916 = "HD PROF PRAC/TRADE 87"
       V14917 = "LABOR PT MKT GARDEN 87"
       V14918 = "LABOR PART ROOMERS 87"
       V15136 = "Marital status"
       V15154 = "EMPLOYMENT STATUS 87"
       V15162 = "MAIN OCCUPATION 87"
       V15168 = "Wage per hour 87";

/* Missing values */
if V15162 = 999 then V15162 = .;
if V14913 >= 999998 then V14913 = .;
if V14915 >= 99998 then V14915 = .;
if V14916 >= 999998 then V14916 = .;
if V14917 >= 99998 then V14917 = .;
if V14918 >= 99998 then V14918 = .;
if V15168 >= 9998 then V15168 = .;
run;

/* Sort files by id88 and merge */
proc sort data=tempdir.ind88_90 tagsort; by ID88;
proc sort data=tempdir.fam88    tagsort; by ID88;
run;

data tempdir.fam_ind(compress=yes);
merge tempdir.fam88 tempdir.ind88_90(in=ind88_90); by ID88; if ind88_90;
run;




/* ======== 1989 ======== */

/* Read in 1989 family file and select variables needed for analysis */
data tempdir.fam89(compress=no
                  rename=(V16302=ID89 V16664=OCC89 V16655=EMPSTAT89 V16669=WH89 V16335=H89
                           V17318=REAL_ESTATE89 V17320=VEHICLES89
                           V17323=BUSINESS89 V17326=STOCKS89 V17329=ACCOUNTS89
                           V17332=BONDS89 V17335=DEBT89 V16324=HOUSE89 V16326=MORTGAGE89
                           V16637=MARSTAT89));
infile infile2 LRECL=2506;
input
       V16302  4-7
       V16324  43-48
       V16326  50-55
       V16335  76-79
       V16413  218-223
       V16415  225-229
       V16416  230-235
       V16417  236-240
       V16418  241-245
       V16637  823
       V16655  843
       V16664  855-857
       V16669  868-871
       V17318  1874-1880
       V17320  1882-1887
       V17323  1890-1896
       V17326  1899-1905
       V17329  1909-1915
       V17332  1919-1925
       V17335  1928-1933
       FAMSIZE 175-176
       FAMINC  2322-2328
       RACE    2227
       RACE2   2228;
label
       V16302 = "1989 INTERVIEW NUMBER"
       V16324 = "1989 House value"
       V16326 = "1989 Remaining mortgage"
       V16335 = "HD ANN WRK HRS IN 88"
       V16413 = "HEAD 88 WAGES"
       V16415 = "HD BONUS/OT/COMM 88"
       V16416 = "HD PROF PRAC/TRADE 88"
       V16417 = "LABOR PT MKT GARDEN 88"
       V16418 = "LABOR PART ROOMERS 88"
       V16637 = "Marital status"
       V16655 = "EMPLOYMENT STATUS 88"
       V16664 = "Main OCC 88"
       V16669 = "Wage per hour 88"
       V17318 = "VALUE OF REAL ESTATE"
       V17320 = "...VEHICLES"
       V17323 = "...FARM/BUSINESS"
       V17326 = "...STOCKS"
       V17329 = "...ACCOUNTS"
       V17332 = "...BONDS/INSURANCE"
       V17335 = "...DEBT";
if V16664=999 then V16664=.;
if V16413 >= 999998 then V16413 = .;
if V16415 >= 99998 then V16415 = .;
if V16416 >= 999998 then V16416 = .;
if V16417 >= 99998 then V16417 = .;
if V16418 >= 99998 then V16418 = .;
if V16669 >= 9998 then V16669 = .;
if V16324 >= 999998 then V16324 = .;
if V16326 >= 999998 then V16326 = .;
if V17318 >= 9999998 then V17318 = .; 
if V17320 >= 999998 then V17320 = .;
if V17323 >= 9999998 then V17323 = .;
if V17326 >= 9999998 then V17326 = .;
if V17329 >= 9999998 then V17329 = .;
if V17332 >= 9999998 then V17332 = .;
if V17335 >= 999998 then V17335 = .;
run;

/* Sort files by id89 and merge */
proc sort data=tempdir.fam_ind tagsort; by ID89;
proc sort data=tempdir.fam89   tagsort; by ID89;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam89 tempdir.fam_ind(in=fam_ind); by ID89; if fam_ind;
run;


/* ======== 1990 ======== */

/* Read in 1990 family file and select variables needed for analysis */
data tempdir.fam90(compress=no
                  rename=(V17702=ID90 V18102=OCC90 V18093=EMPSTAT90 V18107=WH90 V17744=H90 V18055=MARSTAT90));
infile infile3 LRECL=2333;
input
       V17702  4-8
       V17744  104-107
       V17829  262-267
       V17831  269-273
       V17832  274-279
       V17833  280-284
       V17834  285-289
       V18055  875
       V18093  918
       V18102  930-932
       V18107  943-946;
label
       V17702 = "1990 INTERVIEW NUMBER"
       V17744 = "HD ANN WRK HRS IN 89"
       V17829 = "HEAD 89 WAGES"
       V17831 = "HD BONUS/OT/COMM 89"
       V17832 = "HD PROF PRAC/TRADE 89"
       V17833 = "LABOR PT MKT GARDEN 89"
       V17834 = "LABOR PART ROOMERS 89"
       V18055 = "Marital status"
       V18093 = "EMPLOYMENT STATUS 89"
       V18107 = "Wage per hour 89";
if V18102=999 then V18102=.;
if V17829 >= 999998 then V17829 = .;
if V17831 >= 99998 then V17831 = .;
if V17832 >= 999998 then V17832 = .;
if V17833 >= 99998 then V17833 = .;
if V17834 >= 99998 then V17834 = .;
if V18107 >= 9998 then V18107 = .;
run;

/* Sort files by id90 and merge */
proc sort data=tempdir.fam_ind tagsort; by ID90;
proc sort data=tempdir.fam90   tagsort; by ID90;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam90 tempdir.fam_ind(in=fam_ind); by ID90; if fam_ind;
run;


/* Part 2 of PSID data manipulation.
   Generate series for hours worked and wage per hour. */

data tempdir.psid;
set tempdir.fam_ind;


/* ======== REMOVE OR REDEFINE MISSING VALUES ======== */

Y88 = V14913 + V14915 + V14916 + V14917 + V14918;
Y89 = V16413 + V16415 + V16416 + V16417 + V16418;
Y90 = V17829 + V17831 + V17832 + V17833 + V17834;

if AGE88>0 and AGE89>0 and AGE90>0;
if H88>0 and H89>0 and H90>0 and H88 < 5840 and H89 < 5840 and H90 < 5840;
if Y88>-999 and Y89>-999 and Y90>-999;

if WH88=. then WH88=-9;
if WH89=. then WH89=-9;
if WH90=. then WH90=-9;

if EMPSTAT88=. THEN EMPSTAT88=-9;
if EMPSTAT89=. THEN EMPSTAT89=-9;
if EMPSTAT90=. THEN EMPSTAT90=-9;
if MARSTAT88=. THEN MARSTAT88=-9;
if MARSTAT89=. THEN MARSTAT89=-9;
if MARSTAT90=. THEN MARSTAT90=-9;
if OCC88=. THEN OCC88=-9;
if OCC89=. THEN OCC89=-9;
if OCC90=. THEN OCC90=-9;
if EDUC88=. THEN EDUC88=-9;

if RACE2 > 1 then RACE = RACE2;

if real_estate89=. then real_estate89=-999;
if vehicles89=. then vehicles89=-999;
if business89=. then business89=-999;
if stocks89=. then stocks89=-999;
if accounts89=. then accounts89=-999;
if bonds89=. then bonds89=-999;
if house89=. then house89=-999;
if mortgage89=. then mortgage89=-999;
if debt89=. then debt89=-999;


file fileref;
put @1   Y88   @11  Y89  @21  Y90
    @31  H88   @39  H89  @47  H90
    @55  WH88  @63  WH89  @71  WH90
    @79  AGE88 @83  AGE89 @87  AGE90
    @91  OCC88 @97  OCC89 @103 OCC90
    @109 EDUC88
    @115 REAL_ESTATE89 @125 VEHICLES89 @135 BUSINESS89
	@145 STOCKS89      @155 ACCOUNTS89 @165 BONDS89
    @175 HOUSE89       @185 MORTGAGE89 @195 DEBT89
    @205 EMPSTAT88     @210 EMPSTAT89  @215 EMPSTAT90 @220 SEX @225 V30001
    @235 MARSTAT88     @238 MARSTAT89  @241 MARSTAT90 @243 FAMSIZE @246 FAMINC
    @254 RACE;
run;
