/* Construct w/h series from PSID data.
   First version: Dec. 2002.
   Merge 1993 to 1995 files. Pick wage and hours worked info */

libname  tempdir 'd:\elast_data\temp\';
filename fileref 'd:\elast_data\outdata\data94.asc';
filename infile0 'd:\psid\data68_01\er68_01i.dat';
filename infile1 'd:\psid\data93\fam93.dat';
filename infile2 'd:\psid\data94\er94f.dat';
filename infile3 'd:\psid\data95\er95f.dat';
filename infile4 'd:\psid\data94hours\hours94.dat';
filename infile5 'd:\psid\data95hours\hours95.dat';
filename infile6 'd:\psid\faminc94_01\faminc94.dat';
filename infile7 'd:\psid\faminc94_01\faminc95.dat';


    /* Read in 1993-1995 cross-year individual file and select variables
      needed for analysis. */

data tempdir.ind93_95(compress=no
                           rename=(V30806=ID93 V33101=ID94 V33201=ID95
                           V30809=AGE93 V33104=AGE94 V33204=AGE95
                           V30820=EDUC93 V32000=SEX));
infile infile0 LRECL=2583;

input
       V30001  2-5
       V30002  6-8
       V30806 1910-1914
       V30807 1915-1916
       V30808 1917-1918
       V30809 1919-1921
       V30820 1944-1945
       V33101 2039-2043
       V33102 2044-2045
       V33103 2046-2047
       V33104 2048-2050
       V33201 2114-2118
       V33202 2119-2120
       V33203 2121-2122
       V33204 2123-2125
       V32000  2038;
label
       V30001 = "1968 INTERVIEW NUMBER 68"
       V30002 = "PERSON NUMBER         68"
       V30806 = "1993 INTERVIEW NUMBER"
       V30807 = "SEQUENCE NUMBER                       93"
       V30808 = "RELATION TO HEAD                      93"
       V30809 = "AGE OF INDIVIDUAL                     93"
       V30820 = "YRS COMPLETED EDUCATION               93"
       V33101 = "1994 INTERVIEW NUMBER"
       V33102 = "SEQUENCE NUMBER                       94"
       V33103 = "RELATION TO HEAD                      94"
       V33104 = "AGE OF INDIVIDUAL                     94"
       V33201 = "1995 INTERVIEW NUMBER"
       V33202 = "SEQUENCE NUMBER                       95"
       V33203 = "RELATION TO HEAD                      95"
       V33204 = "AGE OF INDIVIDUAL                     95"
       V32000  = "SEX OF INDIVIDUAL";

/* Missing values */
IF V30809=99 THEN V30809=.;
IF V30820 IN(99,0) THEN V30820=.;
IF V33104=99 THEN V33104=.;
IF V33204=99 THEN V33204=.;

/* Select those men who were always heads 1993-1995 */
if (V32000 = 1) and
    (V30807 = 1 and V30808 = 10) and
    (V33102 = 1 and V33103 = 10) and
    (V33202 = 1 and V33203 = 10);


run;


/* ======== 1993 ======== */

/* Read in 1993 family file and select variables needed for analysis */
data tempdir.fam93(compress=no
                  rename=(V21602=ID93 V22456=OCC93 V22448=EMPSTAT93 V22470=WH93
                          V21634=H93 V22412=MARSTAT93 V23323=Y93 
                          V21733=Y93FARM V21738=Y93BUS));
infile infile1 LRECL=3331;
input
       V21602  4-8
       V21634  97-100
       V21733  283-289
	   V21738  300-306
       V23323  3212-3218
       V22412  1495
       V22448  1536
       V22456  1547-1549
       V22470  1591-1596 .2
       RACE    3109
       RACE2   3110;
label
       V21602 = "1993 INTERVIEW NUMBER"
       V21634 = "HD 1992 TOTAL WORK HOURS"
       V21733 = "HD 1992 Labor part of farm income"
	   V21738 = "HD 1992 Labor part of uninc bus inc"
       V23323 = "HD 1992 TOTAL LABOR INCOME"
       V22412 = "A3 MARITAL STATUS"
       V22448 = "B1 HEAD 1993 EMPLOYMENT STATUS"
       V22456 = "B9-9A MAIN OCCUPATION: 3 DIGIT (HD-E)"
       V22470 = "B16 PAY/HR-PD HOURLY (HD-E)";
if V23323 >= 9999998 then V23323 = .;
if V21733 >= 9999998 then V21733 = .;
if V21738 >= 9999998 then V21738 = .;
if V22470 >= 998 then V22470 = .;
run;

/* Sort files by id93 and merge */
proc sort data=tempdir.ind93_95 tagsort; by ID93;
proc sort data=tempdir.fam93    tagsort; by ID93;
run;

data tempdir.fam_ind(compress=yes);
merge tempdir.fam93 tempdir.ind93_95(in=ind93_95); by ID93; if ind93_95;
run;




/* ======== 1994 ======== */

/* Read in 1994 family file and select variables needed for analysis */
data tempdir.fam94(compress=no
                  rename=(V2002=ID94 V2033=HOUSE94
                          V2037=MORTG1_94 V2038=MORTG2_94
                          V2068=EMPSTAT94 V2088=WH94
                          V3722=REAL_ESTATE94 V3726=VEHICLES94
                          V3731=BUSINESS94 V3736=STOCKS94 V3742=ACCOUNTS94
                          V3748=BONDS94 V3753=DEBT94
                          V2014=MARSTAT94));
infile infile2 LRECL=3443;
input
       V2002  2-6
       V2014  33
       V2033  59-65
       V2037  76-82
       V2038  83-89
       V2068  143
       V2088  184-192 .2
       V3722  2874-2880
       V3726  2884-2890
       V3731  2895-2901
       V3736  2906-2912
       V3742  2918-2924
       V3748  2930-2936
       V3753  2941-2947
       FAMSIZE 20-21;
 label
       V2002 = "1994 INTERVIEW NUMBER"
       V2014 = "HEAD MARITAL STATUS"
       V2033 = "HOUSE VALUE"
       V2037 = "A24 REM PRINCIPAL MOR 1"
       V2038 = "A24 REM PRINCIPAL MOR 2"
       V2068 = "EMPLOYMENT STATUS"
       V2088 = "Wage per hour"
       V3722 = "OTR REAL ESTATE"
       V3726 = "G120 VALUE VEHICLES"
       V3731 = "OWN FARM/BUSNES"
       V3736 = "OWN STOCKS, ETC"
       V3742 = "G136 AMT ALL ACCTS"
       V3748 = "BOND/INS, ETC"
       V3753 = "OTHER DEBTS";
if V2033 >= 9999998 then V2033 = .;
if V2037 >= 9999998 then V2037 = .;
if V2038 >= 9999998 then V2038 = .;
if V3722 >= 9999998 then V3722 = .; 
if V3726 >= 9999998 then V3726 = .;
if V3731 >= 9999998 then V3731 = .;
if V3736 >= 9999998 then V3736 = .;
if V3742 >= 9999998 then V3742 = .;
if V3748 >= 9999998 then V3748 = .;
if V3753 >= 9999998 then V3753 = .;
if V2088 >= 9998 then V2088 = .;
run;

/* Sort files by id94 and merge */
proc sort data=tempdir.fam_ind tagsort; by ID94;
proc sort data=tempdir.fam94   tagsort; by ID94;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam94 tempdir.fam_ind(in=fam_ind); by ID94; if fam_ind;
run;



/* ======== 1995 ======== */

/* Read in 1995 family file and select variables needed for analysis */
data tempdir.fam95(compress=no
                  rename=(V5002=ID95 V5067=EMPSTAT95 V5087=WH95 V5013=MARSTAT95));
infile infile3 LRECL=3228;
input
       V5002   2-6
       V5013   30
       V5067   136
       V5087   180-188 .2;
label
       V5002 = "1995 INTERVIEW NUMBER"
       V5013 = "Marital status"
       V5067 = "EMPLOYMENT STATUS 94"
       V5087 = "Wage per hour 94";
if V5087 >= 9998 then V5087 = .;
run;

/* Sort files by id95 and merge */
proc sort data=tempdir.fam_ind tagsort; by ID95;
proc sort data=tempdir.fam95   tagsort; by ID95;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam95 tempdir.fam_ind(in=fam_ind); by ID95; if fam_ind;
run;



/* ======== 1994 HOURS ======== */

data tempdir.fam94H(compress=no);
infile infile4 LRECL=109;
input
      ID94    1-5
      H94     21-26 .1;
run;
proc sort data=tempdir.fam_ind tagsort; by ID94;
proc sort data=tempdir.fam94H   tagsort; by ID94;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam94H tempdir.fam_ind(in=fam_ind); by ID94; if fam_ind;
run;


/* ======== 1995 HOURS ======== */

data tempdir.fam95H(compress=no);
infile infile5 LRECL=109;
input
       ID95    1-5
       H95     21-26 .1;
run;
proc sort data=tempdir.fam_ind tagsort; by ID95;
proc sort data=tempdir.fam95H   tagsort; by ID95;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam95H tempdir.fam_ind(in=fam_ind); by ID95; if fam_ind;
run;



/* ======== 1994 INCOME ======== */

data tempdir.fam94Y(compress=no);
infile infile6 LRECL=228;
input
       ID94    1-5
       Y94     98-103
       OCC94   200-202
       FAMINC  10-16;
if Y94 >= 999998 then Y94=.;
if OCC94 = 999 then OCC94 = .;
run;
proc sort data=tempdir.fam_ind tagsort; by ID94;
proc sort data=tempdir.fam94Y   tagsort; by ID94;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam94Y tempdir.fam_ind(in=fam_ind); by ID94; if fam_ind;
run;


/* ======== 1995 INCOME ======== */

data tempdir.fam95Y(compress=no);
infile infile7 LRECL=224;
input
       ID95    1-5
       Y95     95-100
       OCC95   196-198;
if Y95 >= 999998 then Y95 = .;
if OCC95 = 999 then OCC95 = .;
run;
proc sort data=tempdir.fam_ind tagsort; by ID95;
proc sort data=tempdir.fam95Y   tagsort; by ID95;
run;

data tempdir.fam_ind(compress=no);
merge tempdir.fam95Y tempdir.fam_ind(in=fam_ind); by ID95; if fam_ind;
run;






/* Part 2 of PSID data manipulation.
   Generate series for hours worked and wage per hour. */

data tempdir.psid;
set tempdir.fam_ind;





/* ======== REMOVE OR REDEFINE MISSING VALUES ======== */

if AGE93>0 and AGE94>0 and AGE95>0;
if H93>0 and H94>0 and H95>0 and H93 < 5840 and H94 < 5840 and H95 < 5840;
if Y93>-999 and Y94>-999 and Y95>-999;
if Y93FARM>0 then Y93=Y93-Y93FARM;
if Y93BUS>0 then Y93=Y93-Y93BUS;

if WH93=. then WH93=-9;
if WH94=. then WH94=-9;
if WH95=. then WH95=-9;

if EMPSTAT93=. THEN EMPSTAT93=-9;
if EMPSTAT94=. THEN EMPSTAT94=-9;
if EMPSTAT95=. THEN EMPSTAT95=-9;
if MARSTAT93=. THEN MARSTAT93=-9;
if MARSTAT94=. THEN MARSTAT94=-9;
if MARSTAT95=. THEN MARSTAT95=-9;
if OCC93=. THEN OCC93=-9;
if OCC94=. THEN OCC94=-9;
if OCC95=. THEN OCC95=-9;
if EDUC93=. THEN EDUC93=-9;

mortgage94 = mortg1_94 + mortg2_94;
if RACE2 > 1 then RACE = RACE2;

if real_estate94=. then real_estate94=-999;
if vehicles94=. then vehicles94=-999;
if business94=. then business94=-999;
if stocks94=. then stocks94=-999;
if accounts94=. then accounts94=-999;
if bonds94=. then bonds94=-999;
if house94=. then house94=-999;
if mortgage94=. then mortgage94=-999;
if debt94=. then debt94=-999;

/* ======== SAVE DATA ======== */

file fileref;
put @1   Y93   @10  Y94  @19  Y95
    @28  H93   @37  H94  @46  H95
    @55  WH93  @63  WH94  @71  WH95
    @79  AGE93 @83  AGE94 @87  AGE95
    @91  OCC93 @97  OCC94 @103 OCC95
    @109 EDUC93
    @115 REAL_ESTATE94 @125 VEHICLES94 @135 BUSINESS94
    @145 STOCKS94      @155 ACCOUNTS94 @165 BONDS94
    @175 HOUSE94       @185 MORTGAGE94 @195 DEBT94
    @205 EMPSTAT93     @210 EMPSTAT94  @215 EMPSTAT95 @220 SEX @225 V30001
    @235 MARSTAT93     @238 MARSTAT94  @241 MARSTAT95 @243 FAMSIZE @246 FAMINC
    @254 RACE;
run;
